#include "testlib.h"
#include <iostream>


using namespace std;


/*

(n, tlen, test_type, flen)

n - number of strings (-1 for undetermined)
tlen - total string length (-1 for unlimited)
(either n or tlen should not be equal to -1)
test_type - one of the following:
    0 - last string is random
    1 - first and last characters of the last string are the same
    2 - all characters of the last string are the same
    3 - anti-forward test
flen - first string length (-1 for undetermined)

*/


vector<int> prdec(int x) {
    vector<int> res;

    int cur = x;

    int i = 2;
    for (; i * i <= cur; ++i) {
        while (cur % i == 0) {
            res.push_back(i);
            cur /= i;
        }
    }

    if (cur != 1) {
        res.push_back(cur);
    }

    return res;
}


char rand_letter() {
    return rnd.next("[a-z]")[0];
}


string itos(int x) {
    if (x == 0) {
        return "0";
    }

    string s;
    while (x) {
        s += '0' + x % 10;

        x /= 10;
    }

    reverse(s.begin(), s.end());

    return s;
}


string rand_string(int len, char oblg = 0) {
    string s;

    for (int i = 0; i < len; ++i) {
        s += rand_letter();
    }

    if (oblg) {
        s[rnd.next(len)] = oblg;
    }

    return s;
}


string rand_string_sqrt(int len, char oblg = 0) {
    string s;

    vector<int> div(len);

    int divs = min(len, (int)sqrt(len) + 1);
    div[0] = 2;

    for (int i = 1; i < divs; ++i) {
        div[i] = 1;
    }

    if (oblg == 0) {
        oblg = rand_letter();
    }

    shuffle(div.begin(), div.end());

    char c = rand_letter();

    for (int i = 0; i < len; ++i) {
        if (div[i] == 1) {
            c = rand_letter();
        } else if (div[i] == 2) {
            c = oblg;
        }

        s += c;
    }

    return s;
}


string string_of(int len, char c) {
    string s;

    for (int i = 0; i < len; ++i) {
        s += c;
    }

    return s;
}


const int MAX_S = 100000;


int main(int argc, char* argv[]) {
    registerGen(argc, argv, 1);

    int n = atoi(argv[1]);
    int tlen = atoi(argv[2]);
    int ttype = atoi(argv[3]);
    int flen = atoi(argv[4]);

    vector<int> slens;

    if (n == -1) {
        slens = prdec(tlen + 1);
        n = slens.size();

        for (int i = 0; i < n; ++i) {
            --slens[i];
        }

        shuffle(slens.begin(), slens.end() - 1);
    } else {
        slens.resize(n);

        int il = MAX_S / n;

        int lsum = 0;

        if (flen == -1) {
            for (int i = 0; i < n - 1; ++i) {
                slens[i] = rnd.next(max(1, il - 10), il);

                lsum += slens[i];
            }
        } else {
            il = (MAX_S - flen) / (n - 1);

            slens[0] = flen;
            lsum += flen;

            for (int i = 1; i < n - 1; ++i) {
                slens[i] = rnd.next(max(1, il - 10), il);

                lsum += slens[i];
            }
        }

        slens[n - 1] = MAX_S - lsum;
    }

    vector<string> strs(n);

    if (ttype == 4) {
        int oen[] = {6, 10, 12, 18, 52578};

        int lsum = 0;
        for (int i = 1; i <= 5; ++i) {
            slens[n - i] = oen[5 - i];

            lsum += slens[n - i];
        }

        int il = (MAX_S - lsum) / (n - 5);

        for (int i = 1; i < n - 5; ++i) {
            slens[i] = rnd.next(max(1, il - 10), il);

            lsum += slens[i];
        }

        slens[0] = MAX_S - lsum;

        for (int i = 0; i < n - 5; ++i) {
            strs[i] = rand_string(slens[i]);

            for (char &cc : strs[i]) {
                if (cc == 'a') {
                    ++cc;
                }
            }
        }

        for (int i = n - 5; i < n; ++i) {
            for (int j = 0; j < slens[i]; ++j) {
                strs[i] += 'a';
            }
        }
    } else if (ttype == 3) {
        int alot = 70;

        for (int i = 0; i < 26; ++i) {
            for (int j = 0; j < alot; ++j) {
                strs[i * alot + j] = string_of(slens[i * alot + j], 'a' + i);
            }
        }

        for (int i = 26 * alot; i < n; ++i) {
            strs[i] = rand_string(slens[i]);
        }
    } else {
        for (int i = 0; i < n - 2; ++i) {
            strs[i] = rand_string(slens[i]);
        }

        char c = rand_letter();

        strs[n - 2] = rand_string(slens[n - 2], c);

        string s = rand_string(slens[n - 1]);

        if (ttype == 0) {
            int hlen = min((int)s.length(), (int)sqrt(s.length()) * 3);

            for (int j = 0; j < rnd.next(1, hlen); ++j) {
                s[j] = c;
            }

            char c1 = rand_letter();

            for (int j = 0; j < rnd.next(1, hlen); ++j) {
                s[s.length() - j - 1] = c1;
            }
        } else if (ttype == 1) {
            int hlen = min((int)s.length(), (int)sqrt(s.length()) * 3);

            for (int j = 0; j < rnd.next(1, hlen); ++j) {
                s[j] = c;
            }

            for (int j = 0; j < rnd.next(1, hlen); ++j) {
                s[s.length() - j - 1] = c;
            }
        } else if (ttype == 2) {
            for (int j = 0; j < s.length(); ++j) {
                s[j] = c;
            }
        }

        strs[n - 1] = s;
    }

    cout << n << endl;
    for (int i = 0; i < n; ++i) {
        cout << strs[i] << endl;
    }

    return 0;
}
