#include "testlib.h"
#include <bits/stdc++.h>
using namespace std;

// Generate tests that DOES NOT HAVE solution
// First arg - N
// Second arg - M
// Third arg - has '='s or not

int n, m;

class DisjointSetsUnion {
private:
    vector<int> parent;
    vector<int> rnk;

public:
    DisjointSetsUnion(int n) {
        parent.resize(n);
        rnk.resize(n);

        for (int i = 0; i < n; i++) {
            parent[i] = i;
        }
    }

    void makeSet(int v) {
        parent[v] = v;
        rnk[v] = 0;
    }
     
    int findSet(int v) {
        if (v == parent[v]) {
            return v;
        }
        return parent[v] = findSet(parent[v]);
    }
     
    void unionSets(int a, int b) {
        a = findSet(a);
        b = findSet(b);
        if (a != b) {
            if (rnk[a] < rnk[b]) {
                swap(a, b);
            }
            parent[b] = a;
            if (rnk[a] == rnk[b]) {
                rnk[a]++;
            }
        }
    }
};

bool is_solvable(const vector<string> &matr) {
    // Unite equal vertices
    DisjointSetsUnion dsu(n + m);
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (matr[i][j] == '=') {
                dsu.unionSets(i, j + n);
            }
        }
    }

    // Find real number of vertices
    vector<bool> used(n + m);
    vector<int> roots;
    vector<int> link_to_root(n + m);
    int root_count = 0;
    for (int i = 0; i < used.size(); i++) {
        int root = dsu.findSet(i);
        link_to_root[i] = root;
        if (!used[root]) {
            used[root] = true;
            roots.push_back(root);
            root_count++;
        }
    }

    // Rebuild the matrix
    vector<string> zip_matr(root_count);
    for (int i = 0; i < root_count; i++) {
        zip_matr[i].resize(root_count, '?');
    }
    vector<int> zip_roots(n + m);
    for (int i = 0; i < roots.size(); i++) {
        zip_roots[roots[i]] = i;
    }
    for (int i = 0; i < n; i++) {
        for (int j = n; j < n + m; j++) {
            int root_a = zip_roots[dsu.findSet(i)];
            int root_b = zip_roots[dsu.findSet(j)];

            char new_char = matr[i][j - n];
            char &prev_char = zip_matr[root_a][root_b];
            if (prev_char != '?' && prev_char != new_char) {
                // found an error!
                return false;
            } else {
                prev_char = new_char;
            }
        }
    }

    // Do a greedy algo
    vector<int> links_to_children(root_count);
    vector<int> answers(root_count);
    for (int i = 0; i < root_count; i++) {
        for (int j = 0; j < root_count; j++) {
            if (zip_matr[i][j] == '>' || zip_matr[j][i] == '<') {
                links_to_children[i]++;
            }
        }
    }
    set<pair<int, int>> q;
    for (int i = 0; i < root_count; i++) {
        q.insert({links_to_children[i], i});
    }

    while (!q.empty()) {
        auto val = *q.begin();
        q.erase(q.begin());

        if (val.first != 0) {
            return false;
        }

        int index = val.second;
        answers[index]++;
        for (int j = 0; j < root_count; j++) {
            if (zip_matr[j][index] == '>' || zip_matr[index][j] == '<') {
                q.erase({links_to_children[j], j});
                links_to_children[j]--;
                q.insert({links_to_children[j], j});
                answers[j] = max(answers[j], answers[index]);
            }
        }
    }

    // print the answer
    return true;
}

int main(int argc, char **argv) {
    registerGen(argc, argv, 1);

    n = atoi(argv[1]);
    m = atoi(argv[2]);
    int has_equals = atoi(argv[3]);

    string pattern = "[<>" + (has_equals ? string("=") : string("")) + "]";

    while (true) {
        vector<string> try_map(n);
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                try_map[i] += rnd.next(pattern);
            }
        }
        if (!is_solvable(try_map)) {
            cout << n << " " << m << endl;
            for (const auto &it : try_map) {
                cout << it << endl;
            }
            break;
        }
    }
}
