#include "testlib.h"
#include <bits/stdc++.h>
using namespace std;

// Generate tests that have solution
// First arg - N
// Second arg - M
// Third arg - number of coincidences between two sets

class DisjointSetsUnion {
private:
    vector<int> parent;
    vector<int> rnk;

public:
    DisjointSetsUnion(int n) {
        parent.resize(n);
        rnk.resize(n);

        for (int i = 0; i < n; i++) {
            parent[i] = i;
        }
    }

    void makeSet(int v) {
        parent[v] = v;
        rnk[v] = 0;
    }
     
    int findSet(int v) {
        if (v == parent[v]) {
            return v;
        }
        return parent[v] = findSet(parent[v]);
    }
     
    void unionSets(int a, int b) {
        a = findSet(a);
        b = findSet(b);
        if (a != b) {
            if (rnk[a] < rnk[b]) {
                swap(a, b);
            }
            parent[b] = a;
            if (rnk[a] == rnk[b]) {
                rnk[a]++;
            }
        }
    }
};

int main(int argc, char **argv) {
    registerGen(argc, argv, 1);

    int n = atoi(argv[1]);
    int m = atoi(argv[2]);

    // Number of coincidence edges between two sets
    int repeats = atoi(argv[3]);

    // Initial distribution
    vector<int> result(n + m);
    for (int i = 0; i < n + m; i++) {
        result[i] = i;
    }
    shuffle(result.begin(), result.end());
    
    // Set repetitions
    vector<pair<int, int>> pairs;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            pairs.push_back({i, j});
        }
    }
    shuffle(pairs.begin(), pairs.end());

    DisjointSetsUnion dsu(n + m);
    for (int i = 0; i < repeats; i++) {
        dsu.unionSets(pairs[i].first, pairs[i].second + n);
    }

    // Print the matrix
    printf("%d %d\n", n, m);
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            int diff = dsu.findSet(result[i]) - dsu.findSet(result[j + n]);
            if (diff > 0) {
                printf(">");
            } else if (diff == 0) {
                printf("=");
            } else {
                printf("<");
            }
        }
        printf("\n");
    }
}
