#include <cstdio>
#include <set>
#include <string>
#include <vector>
using namespace std;

class DisjointSetsUnion {
private:
    vector<int> parent;
    vector<int> rank;

public:
    DisjointSetsUnion(int n) {
        parent.resize(n);
        rank.resize(n);

        for (int i = 0; i < n; i++) {
            parent[i] = i;
        }
    }

    void makeSet(int v) {
        parent[v] = v;
        rank[v] = 0;
    }
     
    int findSet(int v) {
        if (v == parent[v]) {
            return v;
        }
        return parent[v] = findSet(parent[v]);
    }
     
    void unionSets(int a, int b) {
        a = findSet(a);
        b = findSet(b);
        if (a != b) {
            if (rank[a] < rank[b]) {
                swap(a, b);
            }
            parent[b] = a;
            if (rank[a] == rank[b]) {
                rank[a]++;
            }
        }
    }
};

int main() {
    // Input data
    int n, m;
    scanf("%d%d", &n, &m);

    char buf[1005];

    vector<string> matr(n);
    for (int i = 0; i < n; ++i) {
        scanf("%s", buf);
        matr[i] = string(buf);
    }

    // Unite equal vertices
    DisjointSetsUnion dsu(n + m);
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (matr[i][j] == '=') {
                dsu.unionSets(i, j + n);
            }
        }
    }

    // Find real number of vertices
    vector<bool> used(n + m);
    vector<int> roots;
    vector<int> link_to_root(n + m);
    int root_count = 0;
    for (int i = 0; i < used.size(); i++) {
        int root = dsu.findSet(i);
        link_to_root[i] = root;
        if (!used[root]) {
            used[root] = true;
            roots.push_back(root);
            root_count++;
        }
    }

    // Rebuild the matrix
    vector<string> zip_matr(root_count);
    for (int i = 0; i < root_count; i++) {
        zip_matr[i].resize(root_count, '?');
    }
    vector<int> zip_roots(n + m);
    for (int i = 0; i < roots.size(); i++) {
        zip_roots[roots[i]] = i;
    }
    for (int i = 0; i < n; i++) {
        for (int j = n; j < n + m; j++) {
            int root_a = zip_roots[dsu.findSet(i)];
            int root_b = zip_roots[dsu.findSet(j)];

            char new_char = matr[i][j - n];
            char &prev_char = zip_matr[root_a][root_b];
            if (prev_char != '?' && prev_char != new_char) {
                // found an error!
                printf("No\n");
                return 0;
            } else {
                prev_char = new_char;
            }
        }
    }

    // Do a greedy algo
    vector<int> links_to_children(root_count);
    vector<int> answers(root_count);
    for (int i = 0; i < root_count; i++) {
        for (int j = 0; j < root_count; j++) {
            if (zip_matr[i][j] == '>' || zip_matr[j][i] == '<') {
                links_to_children[i]++;
            }
        }
    }
    set<pair<int, int>> q;
    for (int i = 0; i < root_count; i++) {
        q.insert({links_to_children[i], i});
    }

    while (!q.empty()) {
        auto val = *q.begin();
        q.erase(q.begin());

        if (val.first != 0) {
            printf("No\n");
            return 0;
        }

        int index = val.second;
        answers[index]++;
        for (int j = 0; j < root_count; j++) {
            if (zip_matr[j][index] == '>' || zip_matr[index][j] == '<') {
                q.erase({links_to_children[j], j});
                links_to_children[j]--;
                q.insert({links_to_children[j], j});
                answers[j] = max(answers[j], answers[index]);
            }
        }
    }

    // print the answer
    printf("Yes\n");
    for (int i = 0; i < n; i++) {
        printf("%d ", answers[zip_roots[dsu.findSet(i)]]);
    }
    printf("\n");
    for (int i = n; i < n + m; i++) {
        printf("%d ", answers[zip_roots[dsu.findSet(i)]]);
    }
    printf("\n");
}
